==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-hadoop2-compat/src/main/java/org/apache/hadoop/hbase/metrics/MBeanSourceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.metrics;

import javax.management.ObjectName;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.metrics2.util.MBeans;

/**
 * Hadoop2 metrics2 implementation of an object that registers MBeans.
 */
@InterfaceAudience.Private
public class MBeanSourceImpl implements MBeanSource {

  /**
   * Register an mbean with the underlying metrics system
   * @param serviceName Metrics service/system name
   * @param metricsName name of the metrics obejct to expose
   * @param theMbean the actual MBean
   * @return ObjectName from jmx
   */
  @Override
  public ObjectName register(String serviceName, String metricsName, Object theMbean) {
    return MBeans.register(serviceName, metricsName, theMbean);
  }
}

==> hbase-2.5.7-src.tar.gz: hbase-2.5.7/hbase-hadoop2-compat/src/main/java/org/apache/hadoop/hbase/metrics/MBeanSourceImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.metrics;

import javax.management.ObjectName;
import org.apache.hadoop.metrics2.util.MBeans;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Hadoop2 metrics2 implementation of an object that registers MBeans.
 */
@InterfaceAudience.Private
public class MBeanSourceImpl implements MBeanSource {

  /**
   * Register an mbean with the underlying metrics system
   * @param serviceName Metrics service/system name
   * @param metricsName name of the metrics obejct to expose
   * @param theMbean    the actual MBean
   * @return ObjectName from jmx
   */
  @Override
  public ObjectName register(String serviceName, String metricsName, Object theMbean) {
    return MBeans.register(serviceName, metricsName, theMbean);
  }
}
